<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Country;
use App\Models\Admin;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;

class WorkersController extends Controller
{

    public function __construct()
    {
        $this->middleware(['permission:workers,admin']);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Admin::where('type', 'worker')->orderByDesc('id')->paginate(10);
        $active_rows = Admin::where(['type' => 'worker', 'status' => 'active'])->orderByDesc('id')->paginate(10);
        $not_active_rows = Admin::where(['type' => 'worker', 'status' => 'not_active'])->orderByDesc('id')->paginate(10);
        return view('admin.worker.index', compact('rows', 'not_active_rows', 'active_rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.worker.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'city' => 'required',
            'area' => 'required',
            'email' => 'required|email|unique:admins,email',
            'mobile' => 'required|unique:admins,mobile',
            'status' => 'required|in:active,not_active',
            'password' => 'required|min:6',
        ]);
        $worker = new Admin();
        $worker['name'] = $request['name'];
        $worker['email'] = $request['email'];
        $worker['mobile'] = $request['mobile'];
        $worker['city'] = $request['city'];
        $worker['area'] = $request['area'];
        $worker['type'] = 'worker';
        $worker['status'] = $request->status;
        $worker['password'] = bcrypt($request['password']);
        $worker->save();

        $role = Role::create(['guard_name' => 'admin', 'name' => $worker->email]);

        $permissions = $request['permissions'];
        foreach ($permissions as $permission) {
            $role->givePermissionTo($permission);
        }
        $worker->assignRole($role->name);

        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('workers.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Admin::find($id);
        return view('admin.worker.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:admins,email,' . $id,
            'mobile' => 'required|unique:admins,mobile,' . $id,
            'city' => 'required',
            'area' => 'required',
            'status' => 'required|in:active,not_active',
            'password' => 'nullable|min:6'
        ]);
        $worker = Admin::find($id);
        $worker['name'] = $request['name'];
        $worker['email'] = $request['email'];
        $worker['city'] = $request['city'];
        $worker['area'] = $request['area'];
        $worker['mobile'] = $request['mobile'];
        $worker['status'] = $request['status'];
        if ($request['password']) $worker['password'] = bcrypt($request['password']);

        $worker->update();


        $role = Role::where('name', $worker->email)->first();
        $old_permissions = $worker->getAllPermissions();
        foreach ($old_permissions as $old_permission) {
            $role->revokePermissionTo($old_permission->name);
        }

        foreach ($request['permissions'] as $permission) {
            $role->givePermissionTo($permission);
        }


        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('workers.index');

    }


    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Admin::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->back();
    }

    public function worker_search(Request $request)
    {
        $this->validate($request, [
            'search' => 'required'
        ]);
        $req = $request->search;
        $search = is_numeric($request->search);
        if ($search == 1) {
            $rows = Admin::where('type', 'worker')->where('mobile', 'LIKE', "%$request->search%")->paginate(10);
        } else {
            $rows = Admin::where('type', 'worker')->where('name', 'LIKE', "%$request->search%")->paginate(10);
        }
        return view('admin.worker.search', compact('rows', 'req'));
    }

    public function delete_workers_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = Admin::find($id);
            $user->delete();
        }
        return response()->json(['data' => 'done']);
    }

    public function not_active_workers_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = Admin::find($id);
            $user->status = 'not_active';
            $user->update();
        }
        return response()->json(['data' => 'done']);
    }

    public function active_workers_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = Admin::find($id);
            $user->status = 'active';
            $user->update();
        }
        return response()->json(['data' => 'done']);
    }
}
